@@ -351,7 +351,7 @@ int selectAccept(void)
 void onUsageTimeLimitAlarm(int signo)
 {
   connectMode=ENDCONNECT;
-  err_msg("ERR at %s#%d: no connection from client",__FILE__,__LINE__);
+  err_msg("ERR at %s#%d: duration time out",__FILE__,__LINE__);
 }
 
 /***************************************/
